@@ -7,7 +7,7 @@ test_that(
    infer_pred_horizon(fit_standard_pbc$fast,
                       pred_type = 'risk',
                       pred_horizon = NULL),
-   get_oobag_pred_horizon(fit_standard_pbc$fast)
+   fit_standard_pbc$fast$pred_horizon
   )
 
   expect_equal(
@@ -26,14 +26,17 @@ test_that(
 
   fit_renegade <- fit_standard_pbc$fast
 
+  ph <- fit_standard_pbc$fast$pred_horizon
+
   fit_renegade$pred_horizon <- NULL
-  attr(fit_renegade, 'oobag_pred_horizon') <- NULL
 
   expect_error(infer_pred_horizon(fit_renegade,
                                   pred_type = 'risk',
                                   pred_horizon = NULL),
                regexp = 'could not be found')
 
+  fit_standard_pbc$fast$pred_horizon <- ph
+
  }
 )
 
@@ -44,10 +47,10 @@ test_that(
 
   pbc$surv_y <- Surv(pbc_orsf$time, pbc_orsf$status)
 
-  expect_equal(infer_outcome_type(c('time', 'status'), pbc), 'survival')
-  expect_equal(infer_outcome_type('surv_y', pbc), 'survival')
-  expect_equal(infer_outcome_type('age', pbc), 'regression')
-  expect_equal(infer_outcome_type('sex', pbc), 'classification')
+  expect_equal(infer_tree_type(c('time', 'status'), pbc), 'survival')
+  expect_equal(infer_tree_type('surv_y', pbc), 'survival')
+  expect_equal(infer_tree_type('age', pbc), 'regression')
+  expect_equal(infer_tree_type('sex', pbc), 'classification')
 
  }
 )
